# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.

import os
import sys

sys.path.insert(0, os.path.abspath("../../src/"))

# -- Project information -----------------------------------------------------

project = "zorg"


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    "m2r2",
    "sphinx.ext.autodoc",
    "sphinx.ext.napoleon",
    "sphinx.ext.viewcode",
    "sphinx_autodoc_typehints",
]

source_suffix = [".rst", ".md"]

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# -- napolean extension settings ---------------------------------------------
napoleon_google_docstring = True
napoleon_use_admonition_for_examples = True

# -- autodoc_typehints extension settings ------------------------------------
autodoc_typehints = "none"
always_document_param_types = True
add_module_names = False
typehints_fully_qualified = False

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = []


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = 'sphinx_rtd_theme'

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']



"""Contains the zorg package's main entry point."""

from __future__ import annotations

from typing import Sequence

import clack


class Config(clack.Config):
    """Command-line arguments."""

    @classmethod
    def from_cli_args(cls, argv: Sequence[str]) -> Config:
        """Parses command-line arguments."""
        parser = clack.Parser()

        args = parser.parse_args(argv[1:])
        kwargs = clack.filter_cli_args(args)

        return cls(**kwargs)


def run(cfg: Config) -> int:
    """This function acts as this tool's main entry point."""
    del cfg
    return 0


main = clack.main_factory("zorg", run)
if __name__ == "__main__":
    main()
